Index

C L O P S 
All Classes and Interfaces|All Packages

C

close() - Method in class org.refcodes.loader.Loader
Stop watching and destroy all loaded plugins.

L

Loader<CTX> - Class in org.refcodes.loader
Generic runtime loader that discovers, initializes, and destroys plugins at runtime.
Loader(Class, Path, CTX) - Constructor for class org.refcodes.loader.Loader
Create a new HotPlug manager.

O

org.refcodes.loader - module org.refcodes.loader
 
org.refcodes.loader - package org.refcodes.loader
 

P

Plugin<CTX> - Interface in org.refcodes.loader
Plugin interface (SPI) for plugins to implement.

S

start() - Method in class org.refcodes.loader.Loader
Starts the background watcher thread and performs an initial scan.
C L O P S 
All Classes and Interfaces|All Packages